/*
********************************************************************
(c) MSU Video Group 2003-2006, http://compression.ru/video/
This source code is property of MSU Graphics and Media Lab

This code may be distributed under LGPL
(see http://www.gnu.org/licenses/lgpl.html for more details).

E-mail: video-measure@compression.ru
Author: Alexey Noskov
********************************************************************
*/  

#pragma once

#include "icustomplugin.h"

/*
*	BIPSNR plugin
*	Counts PSNR independently to brightness
*/
class CBIPSNRPlugin : public ICustomPlugin
{
private:
	IMetricPlugin::ID m_bipsnr;
	IMetricPlugin::ID m_bimse;

	int m_width;
	int m_height;
	int m_size;

	int m_frames_num;

	float m_mse_summ;

	int m_table [ 256 ][ 256 ];
	int m_table_transform [ 256 ];

public:
	void Init ( IMetricPlugin::COLORCOMPONENT cc, int width, int height, int &global_id );

	vector< pair <IMetricPlugin::ID, float> >	Measure(vector<IMetricImage*> &images);
	vector< pair <IMetricPlugin::ID, float> >	MeasureAndVisualize(vector<IMetricImage*>&images, BYTE *vis, int vis_pitch);

	virtual vector< pair <IMetricPlugin::ID, pair< vector <int>, wstring> > >	MapIDToFrame(bool visualize);
	vector< pair <IMetricPlugin::ID, float> >			CalculateAverage(bool visualize);
	int									GetVideoNum(bool visualize);

	vector <IMetricPlugin::COLORCOMPONENT> GetSupportedColorcomponents();

	wstring				GetName();
	wstring				GetMetrInfoURL();
	wstring				GetUnit();

	int					GetWidthMultiply();
	int					GetHeightMultiply();

	bool				GetMetrIncline();
	wstring				GetInterfaceName();

	bool				IsConfigurable();
	bool				Config(const wstring &configuration_string);
	void				GetDefaultConfiguration(wstring &def_config);
	int					GetVersion();

private:
	void				VisualizePSNR ( float metr_val, BYTE *b, BYTE *g, BYTE*r );

	void				SetRGB ( BYTE * img, int pitch, int x, int y, BYTE r, BYTE g, BYTE b );
	void				SetRGBA ( BYTE * img, int pitch, int x, int y, float r, float g, float b, float a );

	inline float		MSEToPSNR ( float mse );
};