/*
********************************************************************
(c) MSU Video Group 2003-2006, http://compression.ru/video/
This source code is property of MSU Graphics and Media Lab

This code may be distributed under LGPL
(see http://www.gnu.org/licenses/lgpl.html for more details).

E-mail: video-measure@compression.ru
Author: Oleg Petrov
********************************************************************
*/  

#include "stdafx.h"

#include "icustomplugin.h"
#include "pluginadapter.h"

CPluginAdapter::CPluginAdapter(ICustomPlugin *plugin):
m_plugin(plugin)
{
}

CPluginAdapter::~CPluginAdapter()
{
	delete m_plugin;
}

void	CPluginAdapter::Init(IMetricPlugin::COLORCOMPONENT cc, int width, int height, int &global_id)
{
	m_plugin->Init(cc, width, height, global_id);
}

void	CPluginAdapter::Measure(IMetricImage **images, int images_num, ID *ids, float *res, int &res_num)
{
	vector<IMetricImage*> images_v (images, images + images_num);
	vector< pair <IMetricPlugin::ID, float> > res_v = m_plugin->Measure(images_v);

	res_num = (int)res_v.size();
	for(int i = 0; i < res_num; i++)
	{
		ids[i] = res_v[i].first;
		res[i] = res_v[i].second;
	}
}

void	CPluginAdapter::MeasureAndVisualize(IMetricImage **images, int images_num, ID *ids, float *res, int &res_num, BYTE *visualization, int visualization_pitch)
{
	vector<IMetricImage*> images_v (images, images + images_num);
	vector< pair <IMetricPlugin::ID, float> > res_v = m_plugin->MeasureAndVisualize(images_v, visualization, visualization_pitch);

	res_num = (int)res_v.size();
	for(int i = 0; i < res_num; i++)
	{
		ids[i] = res_v[i].first;
		res[i] = res_v[i].second;
	}
}

void	CPluginAdapter::MapIDToFrame(int &ids_num, ID * ids, int **frames, wchar_t **names, bool visualize)
{
	vector< pair <IMetricPlugin::ID, pair<vector< int>, wstring > > > res =  m_plugin->MapIDToFrame(visualize);
	ids_num = (int)res.size();
	for(int i = 0; i < ids_num; i++)
	{
		ids[i] = res[i].first;
		frames[i][0] = (int)res[i].second.first.size();
		for(int j = 0; j < frames[i][0]; j++)
			frames[i][j+1] = res[i].second.first[j];
		wcscpy(names[i], res[i].second.second.c_str());
	}
}

void	CPluginAdapter::CalculateAverage(ID *ids, float *res, int &res_num, bool visualize)
{
	vector< pair <IMetricPlugin::ID, float> > res_v = m_plugin->CalculateAverage(visualize);

	res_num = (int)res_v.size();
	for(int i = 0; i < res_num; i++)
	{
		ids[i] = res_v[i].first;
		res[i] = res_v[i].second;
	}
}

int		CPluginAdapter::GetVideoNum(bool visualize)
{
	return m_plugin->GetVideoNum(visualize);
}

void	CPluginAdapter::GetSupportedColorcomponents(IMetricPlugin::COLORCOMPONENT *cc, int &cc_num)
{
	vector< IMetricPlugin::COLORCOMPONENT > res = m_plugin->GetSupportedColorcomponents();
	cc_num = (int)res.size();
	for(int i = 0; i < cc_num; i++)
		cc[i] = res[i];
}

void	CPluginAdapter::GetName(wchar_t *name)
{
	wstring str = m_plugin->GetName();
	wcscpy(name, str.c_str());
}

void	CPluginAdapter::GetUnit(wchar_t *unit)
{
	wstring str = m_plugin->GetUnit();
	wcscpy(unit, str.c_str());
}

int		CPluginAdapter::GetWidthMultiply()
{
	return m_plugin->GetWidthMultiply();
}

int		CPluginAdapter::GetHeightMultiply()
{
	return m_plugin->GetHeightMultiply();
}

void	CPluginAdapter::GetInterfaceName(wchar_t *interface_name)
{
	wstring str = m_plugin->GetInterfaceName();
	wcscpy(interface_name, str.c_str());
}
void	CPluginAdapter::GetMetrInfoURL(wchar_t *info_url)
{
	wstring str = m_plugin->GetMetrInfoURL();
	wcscpy(info_url, str.c_str());
}

bool	CPluginAdapter::GetMetrIncline()
{
	return m_plugin->GetMetrIncline();
}

bool	CPluginAdapter::IsConfigurable()
{
	return m_plugin->IsConfigurable();
}

bool	CPluginAdapter::Config(const wchar_t* configuration_line)
{
	wstring config_line(configuration_line);
	return m_plugin->Config(config_line);
}

bool	CPluginAdapter::GetDefaultConfiguration(wchar_t* buf, int buf_size)
{
	if(buf == NULL) return false;

	wstring def_config_line;
	m_plugin->GetDefaultConfiguration(def_config_line);
	if((int)def_config_line.length() >= buf_size) return false;

	memcpy(buf, def_config_line.c_str(), ((def_config_line.length() + 1) * sizeof(wchar_t)));
	return true;
}

int		CPluginAdapter::GetVersion()
{
	return RELEASE_14;
}